@@ -10,31 +10,26 @@ macro_rules! here {
         fn type_name_of<T>(_: T) -> &'static str {
             std::any::type_name::<T>()
         }
-        let name = type_name_of(f);
-        // For function name only:
-        // let fnct = match &name[..name.len()-3].rfind(':') {
-        //    Some(pos) => &name[pos + 1..name.len() - 3],
-        //    None => &name[..name.len()-3],
-        // };
+        let name = type_name_of(f); 
         format!("\n{}:{} {}", file!(), line!(), &name[..name.len()-3])
     }}
 }
 
+/// GreenIt (GI) struct facilitates printing (in green) any
+/// singular type that has Display implemented.
+#[derive(Eq, Debug, Clone, Copy, PartialEq)]
+pub struct GI<T: std::fmt::Display>(pub T);
+impl<T: std::fmt::Display> std::fmt::Display for GI<T> {
+    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+        write!(f, "\x1B[01;92m{}\x1B[0m", self.0.to_string())
+    }
+}
+
 /// Wrapper struct for Generic Sets.
+/// Constructor is not needed, plain brackets GS(&slice) work just as well
 #[derive(Eq, Debug, Clone, Copy, PartialEq)]
 pub struct GS<'a,T>(pub &'a[T]);
-
-
-// impl<'a,T> GS<'a,T> {
-
-    // constructor not needed, plain brackets GS(&slice) work just as well
-    // pub fn from_slice(x: &'a[T]) -> GS<'a,T> { GS(x) }
-
-    // Can associate functions with GS but it is simpler to call them directly
-    // pub fn revs(s: &[T]) -> Vec<T> where T: Copy, 
-    // { s.iter().rev().map(|&x| x).collect::<Vec<T>>() }
-//}
-
+ 
 impl<'a,T> Deref for GS<'a,T> {
     type Target = &'a[T]; // Vec<T>;
     fn deref(& self) -> &Self::Target {
